@@ -1,7 +1,7 @@
 # logger (basicConfig must be called before importing anything)
 import logging
 import sys
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
+logging.basicConfig(stream=sys.stdout, level=logging.INFO)
 
 import platform
 if platform.system() == "Windows":
@@ -24,10 +24,9 @@ if platform.system() == "Windows":
             \nPlease install pywin32 manually.")
             raise RuntimeError("Please install pywin32 manually: https://github.com/mhammond/pywin32")
 
-# standard library imports
+# do not remove this
 from dataclasses import dataclass
-# from tmrl.networking import Server, RolloutWorker, Trainer
-# from tmrl.custom.custom_gym_interfaces import TM2020InterfaceLidar
+
 from tmrl.envs import GenericGymEnv
 from tmrl.config.config_objects import CONFIG_DICT
 
@@ -37,6 +36,6 @@ def get_environment():
     Default TMRL Gym environment for TrackMania 2020.
 
     Returns:
-        env (Gym.Env): An instance of the default TMRL Gym environment
+        Gym.Env: An instance of the default TMRL Gym environment
     """
     return GenericGymEnv(id="real-time-gym-v0", gym_kwargs={"config": CONFIG_DICT})
